# Generated by Django 5.0.4 on 2024-05-08 12:34

import django.utils.timezone
import r_shepard.api.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0016_project_commit_interval_project_last_commit_time_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='container',
            name='container_id',
            field=models.CharField(default=r_shepard.api.models.Container.generate_container_id, help_text='The unique identifier of the container within the project.', max_length=8, verbose_name='Container ID'),
        ),
        migrations.AlterField(
            model_name='container',
            name='cpus',
            field=models.PositiveIntegerField(default=2, help_text='The maximum number of CPU cores the container can use. Will only take effect after restarting the container.', verbose_name='CPU Allocation'),
        ),
        migrations.AlterField(
            model_name='container',
            name='is_running',
            field=models.BooleanField(default=False, help_text='Indicates whether the container is running', verbose_name='Running'),
        ),
        migrations.AlterField(
            model_name='container',
            name='local_url',
            field=models.URLField(default='', help_text="Local URL to access this container's RStudio instance", max_length=1024, verbose_name='Local URL'),
        ),
        migrations.AlterField(
            model_name='container',
            name='port',
            field=models.PositiveIntegerField(default=8787, help_text="The host port on which the container's RStudio instance is accessible locally.", verbose_name='Host Port'),
        ),
        migrations.AlterField(
            model_name='container',
            name='ram',
            field=models.PositiveIntegerField(default=2, help_text='The maximum amount of RAM in GB the container can use. Will only take effect after restarting the container.', verbose_name='RAM Allocation (GB)'),
        ),
        migrations.AlterField(
            model_name='container',
            name='tailscale_funnel_url',
            field=models.URLField(default='', help_text="Tailscale Funnel URL to access this container's RStudio instance from the web", max_length=1024, verbose_name='Tailscale Funnel URL'),
        ),
        migrations.AlterField(
            model_name='container',
            name='tailscale_serve_url',
            field=models.URLField(default='', help_text="Tailscale Serve URL to access this container's RStudio instance from the tailnet", max_length=1024, null=True, verbose_name='Tailscale Serve URL'),
        ),
        migrations.AlterField(
            model_name='project',
            name='commit_interval',
            field=models.PositiveIntegerField(default=15, help_text='Commit interval in minutes.'),
        ),
        migrations.AlterField(
            model_name='project',
            name='last_commit_time',
            field=models.DateTimeField(default=django.utils.timezone.now, help_text='Last time the project was committed to the Git repository.'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-05-08 13:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0017_alter_container_container_id_alter_container_cpus_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='description',
            field=models.CharField(default='', help_text='A short description of your project (max. 1025 characters)', max_length=1024),
        ),
    ]
